==> central-repository-3.60.0.zip: com/microej/library/util/kf-util/2.5.0/CHANGELOG-2.5.0.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 2.5.0 - 2020-11-25

### Added

  - Update to MMM.

### Changed

  - **WARNING:** Replace eclasspath logging implementation by ej.util.message.

## 2.4.2 - 2019-08-06

### Added

  - P0095F-1124 Handle null values in Map and List converters.

## 2.4.1 - 2019-07-17

### Fixed

  - P0095F-1087 Fix long converter error.

## 2.4.0 - 2018-05-09

### Added

  - P0095F-140: Added LoggingPermissionCheckDelegate class to log permission checks at runtime.

## 2.3.0 - 2018-04-09

### Added

  - P0095F-211: Add synchronization support for KFList
  - P0095F-209: KFList2: optimized for size implementation

## 2.2.1 - 2018-02-20

### Fixed

  - Removed a leftover debugging trace.

## 2.2.0 - 2018-02-20

### Added

  - WI 2073: Added converters for all wrapper types (Boolean, Byte, Character, Double, Float, Integer, Long, Short) and for List.

### Fixed

  - WI 2073: Fixed Map converter to allow for more complex combinations (e.g. Map<Integer, Double>).

## 2.1.0 - 2017-11-23

### Added

  - WI 20487: Implement a Multi-App enabled Collection: KFList.

## 2.0.1 - 2017-03-19

### Fixed

  - WI 19335: artifact do not contain the mandatory public confs.

## 2.0.0 - 2017-02-17

### Fixed

  - WI 19103: com.microej.kf.util shouldn't have a dependency on ecom.

## 1.4.1 - 2017-01-11

### Added

  - Added mising licence and readme.

## 1.4.0 - 2016-12-23

### Added

  - Moved into com.microej.library.util#kf-util with the package name "com.microej.kf.util".

## 1.3.0 - 2016-02-03

### Added

  - Added HardwareDescriptorConverter.

## 1.2.0 - 2016-02-03

### Added

  - Added IProgressMonitor Converter and Proxy.

## 1.1.0 - 2016-05-23

### Added

  - Added KErnelSupport.stopFeature().

## 1.0.0 - 2015-10-30

### Added

  - Initial public revision.

---
_Copyright 2016-2020 MicroEJ Corp. All rights reserved._  
_Use of this source code is governed by a BSD-style license that can be found with this software._

==> central-repository-3.62.0.zip: com/microej/library/util/kf-util/2.8.0/CHANGELOG-2.8.0.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 2.8.0 - 2024-04-24

### Added

- Add Kernel Security Policy Manager
  - KernelSecurityPolicyManager implementation
  - Json parser implementation

### Changed

- Upgrade KF version from 1.6.1 to 1.7.0
- Fix an issue with SharedServiceRegistryKF register and unregister methods that didn't trigger security manager permission check properly.

## 2.7.1 - 2024-02-29

### Changed

- Add SharedServiceRegistry as a Required Type.

## 2.7.0 - 2023-10-18

### Added

- Add KF Registry & Loader SharedServices implementations.
- Add KF Registry & Loader ShareProperties implementations.
- Move-in and update the SharedService KF testsuite from Wadapps Framework

### Changed

- Update the license.

## 2.6.0 - 2021-03-22

### Added

- Add observable extension which can handle heterogeneous observers.
- Add simple observable extension which can handle heterogeneous observers.

## 2.5.0 - 2020-11-25

### Added

  - Update to MMM.

### Changed

  - **WARNING:** Replace eclasspath logging implementation by ej.util.message.

## 2.4.2 - 2019-08-06

### Added

  - P0095F-1124 Handle null values in Map and List converters.

## 2.4.1 - 2019-07-17

### Fixed

  - P0095F-1087 Fix long converter error.

## 2.4.0 - 2018-05-09

### Added

  - P0095F-140: Added LoggingPermissionCheckDelegate class to log permission checks at runtime.

## 2.3.0 - 2018-04-09

### Added

  - P0095F-211: Add synchronization support for KFList
  - P0095F-209: KFList2: optimized for size implementation

## 2.2.1 - 2018-02-20

### Fixed

  - Removed a leftover debugging trace.

## 2.2.0 - 2018-02-20

### Added

  - WI 2073: Added converters for all wrapper types (Boolean, Byte, Character, Double, Float, Integer, Long, Short) and for List.

### Fixed

  - WI 2073: Fixed Map converter to allow for more complex combinations (e.g. Map<Integer, Double>).

## 2.1.0 - 2017-11-23

### Added

  - WI 20487: Implement a Multi-App enabled Collection: KFList.

## 2.0.1 - 2017-03-19

### Fixed

  - WI 19335: artifact do not contain the mandatory public confs.

## 2.0.0 - 2017-02-17

### Fixed

  - WI 19103: com.microej.kf.util shouldn't have a dependency on ecom.

## 1.4.1 - 2017-01-11

### Added

  - Added mising licence and readme.

## 1.4.0 - 2016-12-23

### Added

  - Moved into com.microej.library.util#kf-util with the package name "com.microej.kf.util".

## 1.3.0 - 2016-02-03

### Added

  - Added HardwareDescriptorConverter.

## 1.2.0 - 2016-02-03

### Added

  - Added IProgressMonitor Converter and Proxy.

## 1.1.0 - 2016-05-23

### Added

  - Added KErnelSupport.stopFeature().

## 1.0.0 - 2015-10-30

### Added

  - Initial public revision.

---  
_Copyright 2016-2024 MicroEJ Corp. All rights reserved._  
_Use of this source code is governed by a BSD-style license that can be found with this software._
